"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const toReadableStream = require("to-readable-stream");
const model_id_1 = require("../util/model-id");
const model_config_file_1 = require("../subcommands/model/model-config-file");
const get_random_string_1 = require("../util/get-random-string");
const model_version_package_readable_stream_from_cache_or_cloud_1 = require("../util/model-version-package-readable-stream-from-cache-or-cloud");
const MODELS_DIR = 'models';
function runBestEffortBackgroundTask(fn, ...args) {
    (async () => {
        try {
            await fn(...args);
        }
        catch (ex) { }
    })();
}
function InstallModelVersionPackages(spawner, bearerToken) {
    return async function installModelVersionPackages(models) {
        let changed = false;
        if (models) {
            await Promise.all(Object.entries(models).map(async ([id, version]) => {
                changed = changed || (await installModel(id, version)).changed;
            }));
        }
        return { changed };
    };
    async function installModel(id, version) {
        let changed = false;
        const { publisher, name } = model_id_1.ModelId.parse(id);
        const destinationDir = path_1.posix.join(MODELS_DIR, publisher, name);
        let installedVersion = undefined;
        try {
            const parsed = await readModelJson(destinationDir);
            installedVersion = parsed.version;
        }
        catch (_) {
            // TODO finer-grained error handling
        }
        if (installedVersion !== version) {
            changed = true;
            const tmpId = get_random_string_1.getRandomString();
            const tmpDir = `${destinationDir}.${tmpId}.download`;
            await spawner.mkdirp(tmpDir);
            try {
                await spawner.untar(await model_version_package_readable_stream_from_cache_or_cloud_1.modelVersionPackageCacheGetReadableStream({ id, version, bearerToken }), tmpDir);
                const fileNames = await spawner.readdir(tmpDir);
                if (fileNames.length !== 1 || !fileNames[0]) {
                    throw new Error('Expected package to contain single directory');
                }
                function modelJsonUpdater(modelJson) {
                    return Object.assign({}, modelJson, { version });
                }
                updateModelJson(path_1.posix.join(tmpDir, fileNames[0]), modelJsonUpdater);
                await spawner.rimraf(destinationDir);
                await spawner.mkdirp(path_1.dirname(destinationDir));
                await spawner.run({
                    exe: 'mv',
                    args: [
                        spawner.resolvePath(tmpDir, fileNames[0]),
                        spawner.resolvePath(destinationDir),
                    ],
                });
            }
            finally {
                runBestEffortBackgroundTask(spawner.rimraf, tmpDir);
            }
        }
        return { changed };
        async function readModelJson(dir) {
            const output = await spawner.run({
                exe: 'cat',
                args: [spawner.resolvePath(dir, model_config_file_1.MODEL_CONFIG_FILE_NAME)],
            });
            const parsed = JSON.parse(output);
            return parsed;
        }
        async function updateModelJson(dir, updater) {
            const parsed = await readModelJson(dir);
            const updated = updater(parsed);
            const serialized = JSON.stringify(updated, null, 2);
            await spawner.run({
                exe: 'dd',
                args: [`of=${spawner.resolvePath(dir, model_config_file_1.MODEL_CONFIG_FILE_NAME)}`],
                input: toReadableStream(serialized),
            });
        }
    }
}
exports.InstallModelVersionPackages = InstallModelVersionPackages;
//# sourceMappingURL=install-models.js.map