"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const target_protocol_1 = require("../util/target-protocol");
const constants_1 = require("../constants");
const alwayscli_1 = require("@alwaysai/alwayscli");
const find_or_write_app_json_file_component_1 = require("./find-or-write-app-json-file-component");
const check_user_is_logged_in_component_1 = require("./check-user-is-logged-in-component");
const find_or_write_dockerfile_component_1 = require("./find-or-write-dockerfile-component");
const required_with_yes_message_1 = require("../util/required-with-yes-message");
const target_json_yes_component_1 = require("./target-json-yes-component");
const target_json_prompt_component_1 = require("./target-json-prompt-component");
const DOCKER_IMAGE_ID_INITIAL_VALUE = `${constants_1.DOCKER_HUB_EDGEIQ_REPOSITORY_NAME}:${constants_1.DOCKER_FALLBACK_TAG_NAME}`;
async function appConfigureComponent(props) {
    const { yes, targetHostname, targetPath, targetProtocol } = props;
    await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes });
    await find_or_write_app_json_file_component_1.findOrWriteAppJsonFileComponent({ yes });
    await find_or_write_dockerfile_component_1.findOrWriteDockerfileComponent({ yes });
    if (yes) {
        switch (targetProtocol) {
            case undefined: {
                throw new alwayscli_1.UsageError(required_with_yes_message_1.RequiredWithYesMessage('protocol'));
            }
            case 'docker:': {
                await target_json_yes_component_1.targetJsonYesComponent({
                    targetConfig: {
                        targetProtocol,
                        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
                    },
                    weAreInAppConfigure: true,
                });
                break;
            }
            case 'ssh+docker:': {
                if (!targetHostname) {
                    throw new alwayscli_1.UsageError(required_with_yes_message_1.RequiredWithYesMessage('hostname', undefined, `If "protocol" is "${target_protocol_1.TargetProtocol['ssh+docker:']}"`));
                }
                if (!targetPath) {
                    throw new alwayscli_1.UsageError(required_with_yes_message_1.RequiredWithYesMessage('path', undefined, `If "protocol" is "${target_protocol_1.TargetProtocol['ssh+docker:']}"`));
                }
                await target_json_yes_component_1.targetJsonYesComponent({
                    targetConfig: {
                        targetProtocol,
                        targetHostname,
                        targetPath,
                        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
                    },
                    weAreInAppConfigure: true,
                });
                break;
            }
            default: {
                throw new Error(constants_1.THIS_SHOULD_NEVER_HAPPEN_MESSAGE);
            }
        }
    }
    else {
        // !yes: run the prompted interface
        await target_json_prompt_component_1.targetJsonPromptComponent({
            targetHostname,
            targetPath,
            targetProtocol,
        });
    }
}
exports.appConfigureComponent = appConfigureComponent;
//# sourceMappingURL=app-configure-component.js.map