"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const logSymbols = require("log-symbols");
const alwayscli_1 = require("@alwaysai/alwayscli");
const app_config_file_1 = require("../util/app-config-file");
const target_config_file_1 = require("../util/target-config-file");
const js_spawner_1 = require("../spawner/js-spawner");
const app_installer_1 = require("../app-installer");
const spin_on_promise_1 = require("../util/spin-on-promise");
const echo_1 = require("../util/echo");
const cognito_auth_1 = require("../util/cognito-auth");
const constants_1 = require("../constants");
const target_json_prompt_component_1 = require("./target-json-prompt-component");
const missing_file_please_run_app_configure_message_1 = require("../util/missing-file-please-run-app-configure-message");
const find_or_write_private_key_file_component_1 = require("./find-or-write-private-key-file-component");
const check_ssh_connectivity_component_1 = require("./check-ssh-connectivity-component");
const create_target_directory_component_1 = require("./create-target-directory-component");
const confirm_write_file_prompt_component_1 = require("./confirm-write-file-prompt-component");
const build_docker_image_component_1 = require("./build-docker-image-component");
const check_user_is_logged_in_component_1 = require("./check-user-is-logged-in-component");
async function appDeployComponent(props) {
    const { yes } = props;
    await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes });
    if (!app_config_file_1.appConfigFile.exists()) {
        throw new alwayscli_1.TerseError(missing_file_please_run_app_configure_message_1.MissingFilePleaseRunAppConfigureMessage(app_config_file_1.appConfigFile.name));
    }
    if (!fs_1.existsSync(constants_1.DOCKERFILE)) {
        throw new alwayscli_1.TerseError(missing_file_please_run_app_configure_message_1.MissingFilePleaseRunAppConfigureMessage(constants_1.DOCKERFILE));
    }
    let ranTargetJsonPromptComponent = false;
    if (!target_config_file_1.targetConfigFile.exists()) {
        if (yes) {
            throw new alwayscli_1.TerseError(missing_file_please_run_app_configure_message_1.MissingFilePleaseRunAppConfigureMessage(constants_1.TARGET_JSON_FILE_NAME));
        }
        const confirmed = await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({
            fileName: undefined,
            description: 'Target configuration',
        });
        if (!confirmed) {
            throw new alwayscli_1.TerseError('Unable to proceed without a target configuration');
        }
        await target_json_prompt_component_1.targetJsonPromptComponent();
        ranTargetJsonPromptComponent = true;
    }
    const bearerToken = await cognito_auth_1.getBearerToken();
    if (!bearerToken) {
        throw new Error('Expected to get bearer token');
    }
    const appConfig = app_config_file_1.appConfigFile.read();
    const targetHostSpawner = target_config_file_1.targetConfigFile.readHostSpawner();
    const targetConfig = target_config_file_1.targetConfigFile.read();
    const sourceSpawner = js_spawner_1.JsSpawner();
    const hostAppInstaller = app_installer_1.AppInstaller(targetHostSpawner, bearerToken);
    // Protocol-specific installation steps
    switch (targetConfig.targetProtocol) {
        case 'ssh+docker:': {
            const { targetHostname, targetPath } = targetConfig;
            if (!ranTargetJsonPromptComponent) {
                // If we ran the targetJsonPromptComponent we can skip these checks
                await find_or_write_private_key_file_component_1.findOrWritePrivateKeyFileComponent({ yes, weAreInAppConfigure: false });
                await check_ssh_connectivity_component_1.checkSshConnectivityComponent({ targetHostname });
                await create_target_directory_component_1.createTargetDirectoryComponent({ targetHostname, targetPath });
            }
            await spin_on_promise_1.spinOnPromise(hostAppInstaller.installSource(sourceSpawner), 'Copy application to target');
        }
    }
    let hasModels = false;
    if (appConfig.models) {
        const ids = Object.keys(appConfig.models);
        if (ids.length > 0) {
            hasModels = true;
            await spin_on_promise_1.spinOnPromise(hostAppInstaller.installModels(appConfig.models), `Model${ids.length > 1 ? 's' : ''} ${ids.join(' ')}`);
        }
    }
    if (!hasModels) {
        echo_1.echo(`${logSymbols.warning} Application has no models`);
    }
    const dockerImageId = await build_docker_image_component_1.buildDockerImageComponent({ targetHostSpawner });
    target_config_file_1.targetConfigFile.update(targetConfiguration => {
        targetConfiguration.dockerImageId = dockerImageId;
    });
    const targetSpawner = target_config_file_1.targetConfigFile.readContainerSpawner();
    const targetAppInstaller = app_installer_1.AppInstaller(targetSpawner, bearerToken);
    await spin_on_promise_1.spinOnPromise(targetAppInstaller.installVirtualenv(), 'Install python virtualenv');
    await spin_on_promise_1.spinOnPromise(targetAppInstaller.installPythonDeps(), 'Install python dependencies');
}
exports.appDeployComponent = appDeployComponent;
//# sourceMappingURL=app-deploy-component.js.map