"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ora = require("ora");
const ssh_spawner_1 = require("../spawner/ssh-spawner");
const js_spawner_1 = require("../spawner/js-spawner");
const echo_1 = require("../util/echo");
const alwayscli_1 = require("@alwaysai/alwayscli");
async function checkForDockerComponent(props = {}) {
    const spawner = props.targetHostname
        ? ssh_spawner_1.SshSpawner({ targetHostname: props.targetHostname })
        : js_spawner_1.JsSpawner();
    {
        const spinner = ora('Check docker executable').start();
        spinner.start();
        try {
            await spawner.run({ exe: 'docker', args: ['--version'] });
            spinner.succeed();
        }
        catch (ex) {
            spinner.fail('Command "docker --version" failed');
            echo_1.echo(ex.message);
            echo_1.echo(`Please install docker${props.targetHostname ? ' on your target system' : ''}, or \nverify the existing installation if there is one.`);
            echo_1.echo();
            echo_1.echo('For installation instructions for your operating system, see:');
            echo_1.echo();
            echo_1.echo('  https://docs.docker.com/install/');
            echo_1.echo();
            throw new alwayscli_1.TerseError('Failed to run "docker --version"');
        }
    }
    {
        const spinner = ora('Check docker permissions').start();
        spinner.start();
        try {
            await spawner.run({ exe: 'docker', args: ['run', '--rm', 'hello-world'] });
            spinner.succeed();
        }
        catch (ex) {
            spinner.fail('Command "docker run hello-world" failed');
            echo_1.echo(ex.message);
            echo_1.echo('Please double-check that you\'ve complete the "Manage Docker as a non-root user" post-install steps described here:');
            echo_1.echo();
            echo_1.echo('  https://docs.docker.com/install/linux/linux-postinstall/');
            echo_1.echo();
            throw new alwayscli_1.TerseError('Failed to run "docker run hello-world"');
        }
    }
}
exports.checkForDockerComponent = checkForDockerComponent;
//# sourceMappingURL=check-for-docker-component.js.map