"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ora = require("ora");
const delay = require("delay");
const ssh_spawner_1 = require("../spawner/ssh-spawner");
const alwayscli_1 = require("@alwaysai/alwayscli");
const TEN_SECONDS = 10 * 1000;
exports.TIMED_OUT_CONNECTING_TO = 'Timed out connecting to';
async function checkSshConnectivityComponent(props) {
    const { targetHostname, warnOrFail = 'fail' } = props;
    const spinner = ora('Check SSH connectivity').start();
    const spawner = ssh_spawner_1.SshSpawner({ targetHostname });
    try {
        await Promise.race([
            spawner.run({ exe: 'echo' }),
            delay.reject(TEN_SECONDS, {
                value: new alwayscli_1.TerseError(`${exports.TIMED_OUT_CONNECTING_TO} "${targetHostname}"`),
            }),
        ]);
        spinner.succeed();
    }
    catch (exception) {
        spinner[warnOrFail]();
        throw exception;
    }
}
exports.checkSshConnectivityComponent = checkSshConnectivityComponent;
//# sourceMappingURL=check-ssh-connectivity-component.js.map