"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const ora = require("ora");
const constants_1 = require("../constants");
const confirm_write_file_prompt_component_1 = require("./confirm-write-file-prompt-component");
const APPLICATION_SOURCE_CODE = `import cv2
import edgeiq

def main():
    # Your alwaysAI app goes here!
    print("This is a stub of an alwaysAI application")

if __name__ == "__main__":
    main()
`;
const WRITE_MESSAGE = `Write ${constants_1.APP_PY_FILE_NAME}`;
const FOUND_MESSAGE = `Found ${constants_1.APP_PY_FILE_NAME}`;
async function findOrWriteAppPyFileComponent(props) {
    const { yes } = props;
    if (fs_1.existsSync(constants_1.APP_PY_FILE_NAME)) {
        ora(FOUND_MESSAGE).succeed();
    }
    else {
        // !exists
        const confirmed = yes ||
            (await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({
                fileName: constants_1.APP_PY_FILE_NAME,
                description: 'Application file',
            }));
        if (confirmed) {
            try {
                fs_1.writeFileSync(constants_1.APP_PY_FILE_NAME, APPLICATION_SOURCE_CODE, { flag: 'wx' });
                ora(WRITE_MESSAGE).succeed();
            }
            catch (exception) {
                if (exception.code === 'EEXIST') {
                    // Unlikely scenario that the file did not exist but now does
                    ora(FOUND_MESSAGE).succeed();
                }
                else {
                    ora(WRITE_MESSAGE).fail();
                    throw exception;
                }
            }
        }
    }
}
exports.findOrWriteAppPyFileComponent = findOrWriteAppPyFileComponent;
//# sourceMappingURL=find-or-write-app-py-file-component.js.map