"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const ora = require("ora");
const semver_1 = require("semver");
const download = require("download");
const constants_1 = require("../constants");
const confirm_write_file_prompt_component_1 = require("./confirm-write-file-prompt-component");
const alwayscli_1 = require("@alwaysai/alwayscli");
const unable_to_proceed_without_message_1 = require("../util/unable-to-proceed-without-message");
const WRITE_MESSAGE = `Write ${constants_1.DOCKERFILE}`;
const FOUND_MESSAGE = `Found ${constants_1.DOCKERFILE}`;
async function findOrWriteDockerfileComponent(props) {
    const { yes } = props;
    if (fs_1.existsSync(constants_1.DOCKERFILE)) {
        ora(FOUND_MESSAGE).succeed();
    }
    else {
        // !exists
        const confirmed = yes || (await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({ fileName: constants_1.DOCKERFILE }));
        if (!confirmed) {
            throw new alwayscli_1.TerseError(unable_to_proceed_without_message_1.UnableToProceedWithoutMessage(constants_1.DOCKERFILE));
        }
        const spinner = ora(WRITE_MESSAGE).start();
        const buffer = await download(`https://registry.hub.docker.com/v1/repositories/${constants_1.DOCKER_HUB_EDGEIQ_REPOSITORY_NAME}/tags`);
        const serialized = buffer.toString('utf8');
        const parsed = JSON.parse(serialized);
        const names = parsed.map(({ name }) => name);
        const semverNames = names.filter(name => Boolean(semver_1.valid(name)));
        const sortedSemverNames = semverNames.sort(semver_1.compare);
        const greatestSemver = sortedSemverNames.slice(-1)[0] || constants_1.DOCKER_FALLBACK_TAG_NAME;
        try {
            fs_1.writeFileSync(constants_1.DOCKERFILE, `FROM ${constants_1.DOCKER_HUB_EDGEIQ_REPOSITORY_NAME}:${greatestSemver}\n`, {
                flag: 'wx',
            });
            spinner.succeed();
        }
        catch (exception) {
            if (exception.code === 'EEXIST') {
                // Unlikely scenario that the file did not exist but now does
                spinner.succeed(FOUND_MESSAGE);
            }
            else {
                spinner.fail();
                throw exception;
            }
        }
    }
}
exports.findOrWriteDockerfileComponent = findOrWriteDockerfileComponent;
//# sourceMappingURL=find-or-write-dockerfile-component.js.map