"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const child_process_1 = require("child_process");
const util_1 = require("util");
const ora = require("ora");
const alwayscli_1 = require("@alwaysai/alwayscli");
const constants_1 = require("../constants");
const confirm_write_file_prompt_component_1 = require("./confirm-write-file-prompt-component");
const missing_file_please_run_app_configure_message_1 = require("../util/missing-file-please-run-app-configure-message");
const unable_to_proceed_without_message_1 = require("../util/unable-to-proceed-without-message");
const WRITE_MESSAGE = `Write ${constants_1.PRIVATE_KEY_FILE_PRETTY_PATH}`;
const FOUND_MESSAGE = `Found ${constants_1.PRIVATE_KEY_FILE_PRETTY_PATH}`;
async function findOrWritePrivateKeyFileComponent(props) {
    const { yes, weAreInAppConfigure } = props;
    if (fs_1.existsSync(constants_1.PRIVATE_KEY_FILE_PATH)) {
        ora(FOUND_MESSAGE).succeed();
        // Make sure that the public part of the key is in place. It should be if it
        // was created with ssh-keygen. It might not be if the private key was
        // copied to this host from elsewhere.
        if (!fs_1.existsSync(constants_1.PUBLIC_KEY_FILE_PATH)) {
            const confirmed = yes ||
                (await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({
                    fileName: constants_1.PUBLIC_KEY_FILE_PRETTY_PATH,
                    description: 'Public key file',
                }));
            if (!confirmed) {
                throw new alwayscli_1.TerseError(unable_to_proceed_without_message_1.UnableToProceedWithoutMessage(constants_1.PUBLIC_KEY_FILE_PATH));
            }
            const spinner = ora(`Write ${constants_1.PUBLIC_KEY_FILE_PRETTY_PATH}`).start();
            try {
                const { stdout } = await util_1.promisify(child_process_1.execFile)('ssh-keygen', [
                    '-y',
                    '-f',
                    constants_1.PRIVATE_KEY_FILE_PATH,
                ]);
                await fs_1.writeFileSync(constants_1.PUBLIC_KEY_FILE_PATH, stdout, { flag: 'wx' });
                spinner.succeed();
            }
            catch (exception) {
                if (exception.code === 'EEXIST') {
                    // Unlikely scenario that the file did not exist but now does
                }
                else {
                    throw exception;
                }
            }
        }
    }
    else {
        // !exists
        if (yes && !weAreInAppConfigure) {
            throw new alwayscli_1.TerseError(missing_file_please_run_app_configure_message_1.MissingFilePleaseRunAppConfigureMessage(constants_1.PRIVATE_KEY_FILE_PRETTY_PATH));
        }
        const confirmed = yes ||
            (await confirm_write_file_prompt_component_1.confirmWriteFilePromptComponent({
                fileName: constants_1.PRIVATE_KEY_FILE_PRETTY_PATH,
                description: 'Private key file',
            }));
        if (!confirmed) {
            throw new alwayscli_1.TerseError(unable_to_proceed_without_message_1.UnableToProceedWithoutMessage(constants_1.PRIVATE_KEY_FILE_PRETTY_PATH));
        }
        // ssh-keygen creates the private key file and the corresponding .pub file
        const spinner = ora(WRITE_MESSAGE).start();
        try {
            await util_1.promisify(child_process_1.execFile)('ssh-keygen', [
                '-q',
                '-b',
                '2048',
                '-t',
                'rsa',
                '-N',
                '',
                '-C',
                'Generated by alwaysAI CLI',
                '-f',
                constants_1.PRIVATE_KEY_FILE_PATH,
            ]);
            spinner.succeed();
        }
        catch (exception) {
            spinner.fail();
            throw exception;
        }
    }
}
exports.findOrWritePrivateKeyFileComponent = findOrWritePrivateKeyFileComponent;
//# sourceMappingURL=find-or-write-private-key-file-component.js.map