"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cognito_auth_1 = require("../util/cognito-auth");
const rpc_client_1 = require("../rpc-client");
const alwaysai_user_prompted_login_component_1 = require("./alwaysai-user-prompted-login-component");
const echo_1 = require("../util/echo");
async function searchModelsComponent() {
    const maybeUser = cognito_auth_1.getMaybeCurrentUser();
    if (!maybeUser) {
        await alwaysai_user_prompted_login_component_1.alwaysaiUserPromptedLoginComponent();
    }
    const user = cognito_auth_1.getCurrentUser();
    const rpcClient = await rpc_client_1.RpcClient();
    const userData = await new Promise((resolve, reject) => {
        user.getSession((err) => {
            if (err) {
                reject(err);
            }
            else {
                user.getUserData((err, result) => {
                    if (err) {
                        reject(err);
                    }
                    else {
                        if (result) {
                            resolve(result);
                        }
                        else {
                            reject(new Error('Failed to fetch user data'));
                        }
                    }
                });
            }
        });
    });
    const publicModelVersions = await rpcClient.listPublicModelVersions();
    const privateModelVersions = await rpcClient.listPrivateModelVersions({
        publisher: userData.Username,
    });
    const allModelVersions = [...publicModelVersions, ...privateModelVersions];
    const uniqueIds = [...new Set(allModelVersions.map(({ id }) => id))];
    echo_1.echo(uniqueIds.join('\n'));
}
exports.searchModelsComponent = searchModelsComponent;
//# sourceMappingURL=search-models-component.js.map