"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const target_protocol_prompt_component_1 = require("./target-protocol-prompt-component");
const check_for_docker_component_1 = require("./check-for-docker-component");
const target_config_file_1 = require("../util/target-config-file");
const target_hostname_prompt_component_1 = require("./target-hostname-prompt-component");
const target_path_prompt_component_1 = require("./target-path-prompt-component");
const constants_1 = require("../constants");
const write_target_config_file_component_1 = require("./write-target-config-file-component");
async function targetJsonPromptComponent(props = {}) {
    const currentTargetConfiguration = target_config_file_1.targetConfigFile.readIfExists();
    const targetProtocol = await target_protocol_prompt_component_1.targetProtocolPromptComponent({
        targetProtocol: props.targetProtocol ||
            (currentTargetConfiguration && currentTargetConfiguration.targetProtocol),
    });
    switch (targetProtocol) {
        case 'docker:':
            await check_for_docker_component_1.checkForDockerComponent();
            write_target_config_file_component_1.writeTargetConfigFileComponent({
                targetProtocol,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
            });
            break;
        case 'ssh+docker:':
            let currentTargetHostname;
            let currentTargetPath;
            if (currentTargetConfiguration &&
                currentTargetConfiguration.targetProtocol === 'ssh+docker:') {
                currentTargetHostname = currentTargetConfiguration.targetHostname;
                currentTargetPath = currentTargetConfiguration.targetPath;
            }
            const targetHostname = await target_hostname_prompt_component_1.targetHostnamePromptComponent({
                targetHostname: props.targetHostname || currentTargetHostname,
            });
            await check_for_docker_component_1.checkForDockerComponent({ targetHostname });
            const targetPath = await target_path_prompt_component_1.targetPathPromptComponent({
                targetHostname,
                targetPath: props.targetPath || currentTargetPath,
            });
            await write_target_config_file_component_1.writeTargetConfigFileComponent({
                targetProtocol,
                targetHostname,
                targetPath,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
            });
            break;
        default:
            throw new Error(`Unexpected target protocol ${targetProtocol}`);
    }
}
exports.targetJsonPromptComponent = targetJsonPromptComponent;
//# sourceMappingURL=target-json-prompt-component.js.map