"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const alwayscli_1 = require("@alwaysai/alwayscli");
const prompt_1 = require("../util/prompt");
const create_target_directory_component_1 = require("./create-target-directory-component");
const echo_1 = require("../util/echo");
async function targetPathPromptComponent(props) {
    const DEFAULT_TARGET_PATH = path_1.posix.join('alwaysai', path_1.basename(process.cwd()));
    let writable = false;
    let targetPath;
    let skipPromptForTargetPath;
    if (props.targetPath) {
        // Existing value or command-line input
        targetPath = props.targetPath;
        skipPromptForTargetPath = false;
    }
    else {
        targetPath = DEFAULT_TARGET_PATH;
        ({ skipPromptForTargetPath } = await prompt_1.prompt([
            {
                type: 'confirm',
                name: 'skipPromptForTargetPath',
                message: `Would you like to use the default installation directory "${DEFAULT_TARGET_PATH}"?`,
                initial: true,
            },
        ]));
    }
    while (!writable) {
        if (!skipPromptForTargetPath) {
            ({ targetPath } = await prompt_1.prompt([
                {
                    type: 'text',
                    name: 'targetPath',
                    message: 'Where do you want to run the app? Enter a filesystem path:',
                    initial: targetPath || DEFAULT_TARGET_PATH,
                    validate: value => (!value ? 'Value is required' : true),
                },
            ]));
        }
        try {
            await create_target_directory_component_1.createTargetDirectoryComponent({
                targetHostname: props.targetHostname,
                targetPath,
            });
            writable = true;
        }
        catch (exception) {
            if (exception.code === alwayscli_1.TERSE) {
                skipPromptForTargetPath = false;
                echo_1.echo(exception.message);
            }
            else {
                throw exception;
            }
        }
    }
    return targetPath;
}
exports.targetPathPromptComponent = targetPathPromptComponent;
//# sourceMappingURL=target-path-prompt-component.js.map