#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const subcommands_1 = require("./subcommands");
const constants_1 = require("./constants");
const audit_1 = require("./util/audit");
const environment_1 = require("./environment");
const logSymbols = require("log-symbols");
const root = alwayscli_1.createBranch({
    name: constants_1.CLI_NAME,
    description: 'Manage your alwaysAI assets and environment',
    subcommands: subcommands_1.subcommands,
});
exports.alwaysai = alwayscli_1.createCli(root);
if (module === require.main) {
    alwayscli_1.runAndExit(async () => {
        const args = process.argv.slice(2);
        if (environment_1.ALWAYSAI_AUDIT_LOG) {
            try {
                await audit_1.openAuditLog(environment_1.ALWAYSAI_AUDIT_LOG);
            }
            catch (exception) {
                console.error(`${logSymbols.warning} Failed to open audit log: "${exception.message}"`);
            }
        }
        audit_1.audit(`start "${args.join(' ')}"`);
        const returnValue = await exports.alwaysai(...args);
        await new Promise(resolve => {
            audit_1.audit(`end "${returnValue}"`, () => {
                resolve();
            });
        });
        return returnValue;
    });
}
//# sourceMappingURL=index.js.map