"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const spawner_base_1 = require("./spawner-base");
const gnu_spawner_1 = require("./gnu-spawner");
const docker_spawner_1 = require("./docker-spawner");
const resolve_posix_path_1 = require("../util/resolve-posix-path");
const constants_1 = require("../constants");
function SshDockerSpawner(opts) {
    const resolvePath = resolve_posix_path_1.ResolvePosixPath(docker_spawner_1.APP_DIR);
    return gnu_spawner_1.GnuSpawner(Object.assign({ resolvePath }, spawner_base_1.SpawnerBase(translate)));
    function translate(cmd) {
        const exe = 'ssh';
        const sshArgs = ['-i', constants_1.PRIVATE_KEY_FILE_PATH];
        const expandablePath = path_1.posix.isAbsolute(opts.targetPath)
            ? opts.targetPath
            : `~/${opts.targetPath}`;
        const dockerArgs = [
            'docker',
            'run',
            '--rm',
            '--privileged',
            '--interactive',
            '--network=host',
            '--volume',
            '/dev:/dev',
            '--volume',
            `${expandablePath}:${docker_spawner_1.APP_DIR}`,
        ];
        if (!cmd.superuser) {
            dockerArgs.push('--user', '$(id -u ${USER}):$(id -g ${USER})');
        }
        if (cmd.tty) {
            sshArgs.push('-t');
            dockerArgs.push('--tty');
        }
        if (cmd.expose5000) {
            sshArgs.push('-L', '5000:0.0.0.0:5000');
        }
        sshArgs.push(opts.targetHostname);
        dockerArgs.push('--workdir', resolvePath(cmd.cwd), opts.dockerImageId, cmd.exe);
        if (cmd.args) {
            dockerArgs.push(...cmd.args);
        }
        const translated = {
            exe,
            args: [...sshArgs, ...dockerArgs],
            input: cmd.input,
        };
        return translated;
    }
}
exports.SshDockerSpawner = SshDockerSpawner;
//# sourceMappingURL=ssh-docker-spawner.js.map