"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const yes_cli_input_1 = require("../../cli-inputs/yes-cli-input");
const app_configure_component_1 = require("../../components/app-configure-component");
const target_protocol_cli_input_1 = require("../../cli-inputs/target-protocol-cli-input");
const target_hostname_cli_input_1 = require("../../cli-inputs/target-hostname-cli-input");
const target_path_cli_input_1 = require("../../cli-inputs/target-path-cli-input");
const not_allowed_with_message_1 = require("../../util/not-allowed-with-message");
const os_1 = require("os");
const target_protocol_1 = require("../../util/target-protocol");
exports.appConfigureCliLeaf = alwayscli_1.createLeaf({
    name: 'configure',
    description: 'Configure this directory as an alwaysAI application',
    options: {
        yes: yes_cli_input_1.yesCliInput,
        protocol: target_protocol_cli_input_1.targetProtocolCliInput,
        hostname: target_hostname_cli_input_1.targetHostnameCliInput,
        path: target_path_cli_input_1.targetPathCliInput,
    },
    async action(_, opts) {
        const { yes, hostname, path, protocol } = opts;
        // Preliminary checks that don't help us with type narrowing
        if (protocol === 'docker:' && os_1.platform() !== 'linux') {
            throw new alwayscli_1.UsageError(`Option "protocol" is not allowed to have value "${target_protocol_1.TargetProtocol['docker:']}" if your operating system platform is "${os_1.platform}"`);
        }
        if (protocol === 'docker:' && hostname) {
            throw new alwayscli_1.UsageError(not_allowed_with_message_1.NotAllowedWithMessage('hostname', 'protocol', target_protocol_1.TargetProtocol['docker:']));
        }
        if (protocol === 'docker:' && path) {
            throw new alwayscli_1.UsageError(not_allowed_with_message_1.NotAllowedWithMessage('path', 'protocol', target_protocol_1.TargetProtocol['docker:']));
        }
        return await app_configure_component_1.appConfigureComponent({
            yes,
            targetProtocol: protocol,
            targetHostname: hostname,
            targetPath: path,
        });
    },
});
//# sourceMappingURL=configure.js.map