"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ora = require("ora");
const fs_1 = require("fs");
const alwayscli_1 = require("@alwaysai/alwayscli");
const app_config_file_1 = require("../../../util/app-config-file");
const model_ids_cli_input_1 = require("../../../cli-inputs/model-ids-cli-input");
const rpc_client_1 = require("../../../rpc-client");
const echo_1 = require("../../../util/echo");
const model_version_package_cache_download_from_cloud_1 = require("../../../util/model-version-package-cache-download-from-cloud");
const model_version_package_path_1 = require("../../../util/model-version-package-path");
const cognito_auth_1 = require("../../../util/cognito-auth");
const check_user_is_logged_in_component_1 = require("../../../components/check-user-is-logged-in-component");
exports.addModelsAddCliLeaf = alwayscli_1.createLeaf({
    name: 'add',
    description: 'Add model(s) to this application',
    args: model_ids_cli_input_1.modelIdsCliInput,
    async action(modelIds) {
        app_config_file_1.appConfigFile.read();
        await check_user_is_logged_in_component_1.checkUserIsLoggedInComponent({ yes: false });
        const bearerToken = await cognito_auth_1.getBearerToken();
        if (!bearerToken) {
            throw new Error('Expected user to be logged in');
        }
        const rpcClient = await rpc_client_1.RpcClient();
        const fetched = [];
        for (const modelId of modelIds) {
            const spinner = ora(`Fetch model "${modelId}"`).start();
            try {
                const { version } = await rpcClient.getModelVersion({ id: modelId });
                if (!fs_1.existsSync(model_version_package_path_1.modelVersionPackageCacheGetPath({ id: modelId, version }))) {
                    await model_version_package_cache_download_from_cloud_1.modelVersionPackageCacheDownloadFromCloud({
                        id: modelId,
                        version,
                        bearerToken,
                    });
                }
                fetched.push([modelId, version]);
                spinner.succeed();
            }
            catch (ex) {
                spinner.fail();
                if (ex.code === 'MODEL_VERSION_NOT_FOUND') {
                    throw new alwayscli_1.TerseError(`Model not found: "${modelId}"`);
                }
                throw ex;
            }
        }
        fetched.forEach(([id, version]) => {
            app_config_file_1.appConfigFile.addModel(id, version);
        });
        echo_1.echo();
        echo_1.echo(app_config_file_1.appConfigFile.describeModels());
    },
});
//# sourceMappingURL=add.js.map