"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const target_config_file_1 = require("../../util/target-config-file");
const app_installer_1 = require("../../app-installer");
exports.appShellCliLeaf = alwayscli_1.createLeaf({
    name: 'shell',
    description: 'Launch a bash shell in the target directory',
    options: {
        'no-container': alwayscli_1.createFlagInput({
            description: 'Open the shell on the target host, not in a container on the target host',
        }),
        superuser: alwayscli_1.createFlagInput({
            description: 'Open the shell as superuser "root"',
        }),
    },
    async action(_, opts) {
        const targetConfig = target_config_file_1.targetConfigFile.read();
        switch (targetConfig.targetProtocol) {
            case 'docker:': {
                target_config_file_1.targetConfigFile.readContainerSpawner().runForegroundSync({
                    exe: '/bin/bash',
                    args: ['--rcfile', app_installer_1.ACTIVATE],
                    tty: true,
                    cwd: '.',
                    expose5000: true,
                    superuser: opts.superuser,
                });
                break;
            }
            case 'ssh+docker:': {
                if (opts['no-container']) {
                    if (opts.superuser) {
                        throw new alwayscli_1.TerseError('--superuser is not yet supported with --no-container');
                    }
                    target_config_file_1.targetConfigFile.readHostSpawner().runForegroundSync({
                        exe: '/bin/bash',
                        tty: true,
                        cwd: '.',
                        expose5000: true,
                    });
                }
                else {
                    target_config_file_1.targetConfigFile.readContainerSpawner().runForegroundSync({
                        exe: '/bin/bash',
                        args: ['--rcfile', app_installer_1.ACTIVATE],
                        tty: true,
                        cwd: '.',
                        expose5000: true,
                        superuser: opts.superuser,
                    });
                }
                break;
            }
            default: {
                throw new Error('Unsupported protocol');
            }
        }
    },
});
//# sourceMappingURL=shell.js.map