"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const app_config_file_1 = require("../../util/app-config-file");
const target_config_file_1 = require("../../util/target-config-file");
const app_installer_1 = require("../../app-installer");
// Currently we run the "start" command as a superuser because otherwise we
// cannot connect to the NCS accelerator. It ~should~ be possible to connect to
// the NCS even without --privileged mode, but we need to do the work to set
// that up. See https://movidius.github.io/ncsdk/docker.html
exports.appStartCliLeaf = alwayscli_1.createLeaf({
    name: 'start',
    options: {
        'no-superuser': alwayscli_1.createFlagInput({
            description: 'Launch the application as the login user rather than as the superuser "root"',
        }),
    },
    description: 'Run this application "start" script on the target',
    async action(_, opts) {
        const appConfig = app_config_file_1.appConfigFile.read();
        const script = appConfig.scripts && appConfig.scripts.start;
        if (!script) {
            throw new alwayscli_1.TerseError('This application does not define a "start" script');
        }
        const spawner = target_config_file_1.targetConfigFile.readContainerSpawner();
        const targetConfig = target_config_file_1.targetConfigFile.read();
        switch (targetConfig.targetProtocol) {
            case 'docker:': {
                await spawner.runForeground({
                    exe: '/bin/bash',
                    args: ['-t', '-c', `. ${app_installer_1.ACTIVATE} && ${script}`],
                    tty: true,
                    cwd: '.',
                    expose5000: true,
                    superuser: !opts['no-superuser'],
                });
                return;
            }
            // This case differs from "docker:"" only in the extra single quotes around the command
            case 'ssh+docker:': {
                await spawner.runForeground({
                    exe: '/bin/bash',
                    args: ['-t', '-c', `'. ${app_installer_1.ACTIVATE} && ${script}'`],
                    tty: true,
                    cwd: '.',
                    expose5000: true,
                    superuser: !opts['no-superuser'],
                });
                return;
            }
            default: {
                throw new Error('Unsupported protocol');
            }
        }
    },
});
//# sourceMappingURL=start.js.map