"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const cli_config_1 = require("../../util/cli-config");
const constants_1 = require("../../constants");
const codecs_1 = require("@alwaysai/codecs");
const show = alwayscli_1.createLeaf({
    name: 'show',
    description: `Show your current "${constants_1.CLI_NAME}" configuration`,
    action() {
        return cli_config_1.cliConfigFile.read();
    },
});
const set = alwayscli_1.createLeaf({
    name: 'set',
    description: `Set an "${constants_1.CLI_NAME}" configuration value`,
    options: {
        systemId: alwayscli_1.createOneOfInput({ values: codecs_1.SYSTEM_IDS, required: true }),
    },
    action(_, opts) {
        if (opts.systemId) {
            cli_config_1.cliConfigFile.update(config => {
                config.systemId = opts.systemId;
            });
        }
    },
});
const unset = alwayscli_1.createLeaf({
    name: 'unset',
    description: `Unset an "${constants_1.CLI_NAME}" configuration value`,
    options: {
        all: alwayscli_1.createFlagInput(),
        systemId: alwayscli_1.createFlagInput(),
    },
    action(_, opts) {
        if (opts.all) {
            cli_config_1.cliConfigFile.remove();
            return;
        }
        if (opts.systemId) {
            cli_config_1.cliConfigFile.update(config => {
                delete config.systemId;
            });
        }
    },
});
exports.config = alwayscli_1.createBranch({
    name: 'config',
    hidden: true,
    description: `Show or set "${constants_1.CLI_NAME}" configuration values`,
    subcommands: [show, set, unset],
});
//# sourceMappingURL=index.js.map