"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const model_config_file_1 = require("./model-config-file");
const model_version_package_cache_upload_to_cloud_1 = require("../../util/model-version-package-cache-upload-to-cloud");
const cognito_auth_1 = require("../../util/cognito-auth");
const model_version_package_readable_stream_from_cwd_1 = require("../../util/model-version-package-readable-stream-from-cwd");
const model_version_package_cache_write_readable_stream_1 = require("../../util/model-version-package-cache-write-readable-stream");
const constants_1 = require("../../constants");
const rpc_client_1 = require("../../rpc-client");
exports.modelPublish = alwayscli_1.createLeaf({
    name: 'publish',
    description: 'Publish a new version of a model to the alwaysAI Cloud',
    async action() {
        const modelConfiguration = model_config_file_1.modelConfigFile.read();
        const { id } = modelConfiguration;
        const readable = await model_version_package_readable_stream_from_cwd_1.modelVersionPackageGetReadableStreamFromCwd();
        await model_version_package_cache_write_readable_stream_1.modelVersionPackageCacheWriteReadableStream({
            id,
            version: constants_1.LOCAL_MODEL_VERSION_PACKAGE_NUMBER,
            readable,
        });
        const bearerToken = await cognito_auth_1.getBearerToken();
        if (!bearerToken) {
            throw new Error('must log in');
        }
        const rpcClient = await rpc_client_1.RpcClient();
        const result = await rpcClient.createModelVersion(modelConfiguration);
        await model_version_package_cache_upload_to_cloud_1.modelVersionPackageCacheUploadToCloud({ id, bearerToken, uuid: result.uuid });
        await rpcClient.finalizeModelVersion(result.uuid);
    },
});
//# sourceMappingURL=publish.js.map