"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const alwayscli_1 = require("@alwaysai/alwayscli");
const cognito_auth_1 = require("../../util/cognito-auth");
const alwaysai_user_email_cli_input_1 = require("../../cli-inputs/alwaysai-user-email-cli-input");
const alwaysai_user_password_cli_input_1 = require("../../cli-inputs/alwaysai-user-password-cli-input");
const yes_cli_input_1 = require("../../cli-inputs/yes-cli-input");
const alwaysai_user_prompted_login_component_1 = require("../../components/alwaysai-user-prompted-login-component");
const required_with_yes_message_1 = require("../../util/required-with-yes-message");
const alwaysai_user_login_component_1 = require("../../components/alwaysai-user-login-component");
const echo_1 = require("../../util/echo");
exports.userLogin = alwayscli_1.createLeaf({
    name: 'login',
    description: 'Log in to the alwaysAI Cloud',
    options: {
        yes: yes_cli_input_1.yesCliInput,
        email: alwaysai_user_email_cli_input_1.alwaysaiUserEmailCliInput,
        password: alwaysai_user_password_cli_input_1.alwaysaiUserPasswordCliInput,
    },
    async action(_, { yes, email, password }) {
        if (yes) {
            if (!email || !password) {
                throw new alwayscli_1.UsageError(required_with_yes_message_1.RequiredWithYesMessage('email', 'password'));
            }
            await alwaysai_user_login_component_1.alwaysaiUserLoginComponent({
                alwaysaiUserEmail: email,
                alwaysaiUserPassword: password,
            });
        }
        else {
            const cognitoUser = await cognito_auth_1.getMaybeCurrentUser();
            if (cognitoUser) {
                echo_1.echo(`Already logged in as ${chalk_1.default.bold(cognitoUser.getUsername())}`);
            }
            else {
                await alwaysai_user_prompted_login_component_1.alwaysaiUserPromptedLoginComponent({
                    alwaysaiUserEmail: email,
                    alwaysaiUserPassword: password,
                });
            }
        }
    },
});
//# sourceMappingURL=login.js.map