"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const util_1 = require("util");
const path_1 = require("path");
const mkdirp = require("mkdirp");
const rimraf = require("rimraf");
const rpc_client_1 = require("../rpc-client");
const get_random_string_1 = require("./get-random-string");
const model_version_package_path_1 = require("./model-version-package-path");
const cli_config_1 = require("./cli-config");
const cloud_api_1 = require("@alwaysai/cloud-api");
const download = require("download");
const rimrafAsync = util_1.promisify(rimraf);
async function modelVersionPackageCacheDownloadFromCloud(opts) {
    const { id, version, bearerToken } = opts;
    const rpcApi = await rpc_client_1.RpcClient();
    const modelVersion = await rpcApi.getModelVersion({ id, version });
    const packageUrl = `${cli_config_1.cloudApiUrl}${cloud_api_1.CLOUD_API_MODEL_VERSION_PACKAGES_PATH}/${modelVersion.uuid}`;
    const destinationPath = model_version_package_path_1.modelVersionPackageCacheGetPath({ id, version });
    const destinationDir = path_1.dirname(destinationPath);
    await util_1.promisify(mkdirp)(destinationDir);
    const temporaryDownloadPath = `${destinationPath}.${get_random_string_1.getRandomString()}.download`;
    try {
        await download(packageUrl, destinationDir, {
            headers: { Authorization: `Bearer ${bearerToken}` },
            filename: path_1.basename(temporaryDownloadPath),
        });
        await util_1.promisify(fs_1.rename)(temporaryDownloadPath, destinationPath);
    }
    finally {
        await rimrafAsync(temporaryDownloadPath);
    }
}
exports.modelVersionPackageCacheDownloadFromCloud = modelVersionPackageCacheDownloadFromCloud;
//# sourceMappingURL=model-version-package-cache-download-from-cloud.js.map