"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http = require("http");
const https = require("https");
const url_1 = require("url");
const util_1 = require("util");
const fs_1 = require("fs");
const http_status_codes_1 = require("http-status-codes");
const coded_error_1 = require("@carnesen/coded-error");
const pump = require("pump");
const cli_config_1 = require("./cli-config");
const model_version_package_path_1 = require("./model-version-package-path");
const cloud_api_1 = require("@alwaysai/cloud-api");
const constants_1 = require("../constants");
async function modelVersionPackageCacheUploadToCloud(opts) {
    const { id, bearerToken, uuid } = opts;
    const { protocol, hostname, port } = new url_1.URL(cli_config_1.cloudApiUrl);
    const headers = {
        'Content-Type': 'application/gzip',
        Authorization: `Bearer ${bearerToken}`,
    };
    const packagePath = model_version_package_path_1.modelVersionPackageCacheGetPath({
        id,
        version: constants_1.LOCAL_MODEL_VERSION_PACKAGE_NUMBER,
    });
    const stats = await util_1.promisify(fs_1.stat)(packagePath);
    return new Promise((resolve, reject) => {
        const req = (protocol === 'http:' ? http : https).request({
            hostname,
            port,
            method: 'PUT',
            path: `${cloud_api_1.CLOUD_API_MODEL_VERSION_PACKAGES_PATH}/${uuid}`,
            headers: Object.assign({}, headers, { 'Content-Length': stats.size }),
        });
        req.once('response', (res) => {
            let responseData = '';
            res.on('data', chunk => {
                responseData += chunk;
            });
            res.on('end', () => {
                if (res.statusCode && (res.statusCode === http_status_codes_1.NO_CONTENT || res.statusCode === http_status_codes_1.OK)) {
                    resolve(responseData);
                }
                else {
                    reject(new coded_error_1.CodedError(`Server responded status ${res.statusCode}`, res.statusCode, responseData));
                }
            });
        });
        req.on('error', (err) => {
            reject(new coded_error_1.CodedError(`http request failed "${err.message}"`, err.code));
        });
        const readable = fs_1.createReadStream(packagePath);
        pump(readable, req, err => {
            if (err) {
                reject(err);
            }
        });
    });
}
exports.modelVersionPackageCacheUploadToCloud = modelVersionPackageCacheUploadToCloud;
//# sourceMappingURL=model-version-package-cache-upload-to-cloud.js.map